pub struct BinaryNode<T: PartialOrd> {
pub value: T,
pub left: Option<Box<BinaryNode<T>>>,
pub right: Option<Box<BinaryNode<T>>>,
}Expand description
A node in a binary tree structure.
Each node contains a value of generic type T
and optional left/right child nodes wrapped in Box for heap allocation.
Fields
value: TThe value stored in this node.
left: Option<Box<BinaryNode<T>>>Left child node (less than parent value).
right: Option<Box<BinaryNode<T>>>Right child node (greater than parent value).
Implementations
Sourceimpl<T: PartialOrd> BinaryNode<T>
impl<T: PartialOrd> BinaryNode<T>